@@ -6,10 +6,10 @@ use fil_actors_runtime::{
     actor_error, make_map_with_root_and_bitwidth, resolve_to_id_addr, wasm_trampoline,
     ActorDowncast, ActorError, STORAGE_MARKET_ACTOR_ADDR, SYSTEM_ACTOR_ADDR,
 };
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::RawBytes;
 use fvm_shared::address::Address;
 use fvm_shared::bigint::bigint_ser::BigIntDe;
+use fvm_shared::blockstore::Blockstore;
+use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 use fvm_shared::{MethodNum, HAMT_BIT_WIDTH, METHOD_CONSTRUCTOR};
 use num_derive::FromPrimitive;
@@ -50,13 +50,10 @@ impl Actor {
         // root should be an ID address
         let id_addr = rt
             .resolve_address(&root_key)
-            .ok_or_else(|| actor_error!(USR_ILLEGAL_ARGUMENT, "root should be an ID address"))?;
+            .ok_or_else(|| actor_error!(ErrIllegalArgument, "root should be an ID address"))?;
 
         let st = State::new(rt.store(), id_addr).map_err(|e| {
-            e.downcast_default(
-                ExitCode::USR_ILLEGAL_STATE,
-                "Failed to create verifreg state",
-            )
+            e.downcast_default(ExitCode::ErrIllegalState, "Failed to create verifreg state")
         })?;
 
         rt.create(&st)?;
@@ -70,7 +67,7 @@ impl Actor {
     {
         if &params.allowance < &MINIMUM_VERIFIED_DEAL_SIZE {
             return Err(actor_error!(
-                USR_ILLEGAL_ARGUMENT,
+                ErrIllegalArgument,
                 "Allowance {} below minimum deal size for add verifier {}",
                 params.allowance,
                 params.address
@@ -79,7 +76,7 @@ impl Actor {
 
         let verifier = resolve_to_id_addr(rt, &params.address).map_err(|e| {
             e.downcast_default(
-                ExitCode::USR_ILLEGAL_STATE,
+                ExitCode::ErrIllegalState,
                 format!("failed to resolve addr {} to ID addr", params.address),
             )
         })?;
@@ -88,10 +85,7 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(&st.root_key))?;
 
         if verifier == st.root_key {
-            return Err(actor_error!(
-                USR_ILLEGAL_ARGUMENT,
-                "Rootkey cannot be added as verifier"
-            ));
+            return Err(actor_error!(ErrIllegalArgument, "Rootkey cannot be added as verifier"));
         }
 
         rt.transaction(|st: &mut State, rt| {
@@ -99,7 +93,7 @@ impl Actor {
                 make_map_with_root_and_bitwidth(&st.verifiers, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
                         e.downcast_default(
-                            ExitCode::USR_ILLEGAL_STATE,
+                            ExitCode::ErrIllegalState,
                             "failed to load verified clients",
                         )
                     })?;
@@ -109,38 +103,28 @@ impl Actor {
                 HAMT_BIT_WIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
-                    "failed to load verified clients",
-                )
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
             })?;
 
-            let found = verified_clients
-                .contains_key(&verifier.to_bytes())
-                .map_err(|e| {
-                    e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
-                        format!("failed to get client state for {}", verifier),
-                    )
-                })?;
+            let found = verified_clients.contains_key(&verifier.to_bytes()).map_err(|e| {
+                e.downcast_default(
+                    ExitCode::ErrIllegalState,
+                    format!("failed to get client state for {}", verifier),
+                )
+            })?;
             if found {
                 return Err(actor_error!(
-                    USR_ILLEGAL_ARGUMENT,
+                    ErrIllegalArgument,
                     "verified client {} cannot become a verifier",
                     verifier
                 ));
             }
 
-            verifiers
-                .set(
-                    verifier.to_bytes().into(),
-                    BigIntDe(params.allowance.clone()),
-                )
-                .map_err(|e| {
-                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to add verifier")
-                })?;
+            verifiers.set(verifier.to_bytes().into(), BigIntDe(params.allowance.clone())).map_err(
+                |e| e.downcast_default(ExitCode::ErrIllegalState, "failed to add verifier"),
+            )?;
             st.verifiers = verifiers.flush().map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush verifiers")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verifiers")
             })?;
 
             Ok(())
@@ -156,7 +140,7 @@ impl Actor {
     {
         let verifier = resolve_to_id_addr(rt, &verifier_addr).map_err(|e| {
             e.downcast_default(
-                ExitCode::USR_ILLEGAL_STATE,
+                ExitCode::ErrIllegalState,
                 format!("failed to resolve addr {} to ID addr", verifier_addr),
             )
         })?;
@@ -171,22 +155,19 @@ impl Actor {
                 HAMT_BIT_WIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
-                    "failed to load verified clients",
-                )
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
             })?;
             verifiers
                 .delete(&verifier.to_bytes())
                 .map_err(|e| {
-                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to remove verifier")
+                    e.downcast_default(ExitCode::ErrIllegalState, "failed to remove verifier")
                 })?
                 .ok_or_else(|| {
-                    actor_error!(USR_ILLEGAL_ARGUMENT, "failed to remove verifier: not found")
+                    actor_error!(ErrIllegalArgument, "failed to remove verifier: not found")
                 })?;
 
             st.verifiers = verifiers.flush().map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush verifiers")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verifiers")
             })?;
             Ok(())
         })?;
@@ -207,7 +188,7 @@ impl Actor {
 
         if params.allowance < *MINIMUM_VERIFIED_DEAL_SIZE {
             return Err(actor_error!(
-                USR_ILLEGAL_ARGUMENT,
+                ErrIllegalArgument,
                 "Allowance {} below MinVerifiedDealSize for add verified client {}",
                 params.allowance,
                 params.address
@@ -216,17 +197,14 @@ impl Actor {
 
         let client = resolve_to_id_addr(rt, &params.address).map_err(|e| {
             e.downcast_default(
-                ExitCode::USR_ILLEGAL_STATE,
+                ExitCode::ErrIllegalState,
                 format!("failed to resolve addr {} to ID addr", params.address),
             )
         })?;
 
         let st: State = rt.state()?;
         if client == st.root_key {
-            return Err(actor_error!(
-                USR_ILLEGAL_ARGUMENT,
-                "Rootkey cannot be added as verifier"
-            ));
+            return Err(actor_error!(ErrIllegalArgument, "Rootkey cannot be added as verifier"));
         }
 
         rt.transaction(|st: &mut State, rt| {
@@ -234,17 +212,14 @@ impl Actor {
                 make_map_with_root_and_bitwidth(&st.verifiers, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
                         e.downcast_default(
-                            ExitCode::USR_ILLEGAL_STATE,
+                            ExitCode::ErrIllegalState,
                             "failed to load verified clients",
                         )
                     })?;
             let mut verified_clients =
                 make_map_with_root_and_bitwidth(&st.verified_clients, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
-                    e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
-                        "failed to load verified clients",
-                    )
+                    e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
                 })?;
 
             // Validate caller is one of the verifiers.
@@ -253,21 +228,21 @@ impl Actor {
                 .get(&verifier.to_bytes())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
+                        ExitCode::ErrIllegalState,
                         format!("failed to get Verifier {}", verifier),
                     )
                 })?
                 .ok_or_else(|| {
-                    actor_error!(USR_NOT_FOUND, format!("no such Verifier {}", verifier))
+                    actor_error!(ErrNotFound, format!("no such Verifier {}", verifier))
                 })?;
 
             // Validate client to be added isn't a verifier
             let found = verifiers.contains_key(&client.to_bytes()).map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to get verifier")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to get verifier")
             })?;
             if found {
                 return Err(actor_error!(
-                    USR_ILLEGAL_ARGUMENT,
+                    ErrIllegalArgument,
                     "verifier {} cannot be added as a verified client",
                     client
                 ));
@@ -276,7 +251,7 @@ impl Actor {
             // Compute new verifier cap and update.
             if verifier_cap < &params.allowance {
                 return Err(actor_error!(
-                    USR_ILLEGAL_ARGUMENT,
+                    ErrIllegalArgument,
                     "Add more DataCap {} for VerifiedClient than allocated {}",
                     params.allowance,
                     verifier_cap
@@ -284,18 +259,16 @@ impl Actor {
             }
             let new_verifier_cap = verifier_cap - &params.allowance;
 
-            verifiers
-                .set(verifier.to_bytes().into(), BigIntDe(new_verifier_cap))
-                .map_err(|e| {
-                    e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
-                        format!("Failed to update new verifier cap for {}", verifier),
-                    )
-                })?;
+            verifiers.set(verifier.to_bytes().into(), BigIntDe(new_verifier_cap)).map_err(|e| {
+                e.downcast_default(
+                    ExitCode::ErrIllegalState,
+                    format!("Failed to update new verifier cap for {}", verifier),
+                )
+            })?;
 
             let client_cap = verified_clients.get(&client.to_bytes()).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
+                    ExitCode::ErrIllegalState,
                     format!("Failed to get verified client {}", client),
                 )
             })?;
@@ -307,26 +280,23 @@ impl Actor {
                 params.allowance
             };
 
-            verified_clients
-                .set(client.to_bytes().into(), BigIntDe(client_cap.clone()))
-                .map_err(|e| {
+            verified_clients.set(client.to_bytes().into(), BigIntDe(client_cap.clone())).map_err(
+                |e| {
                     e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
+                        ExitCode::ErrIllegalState,
                         format!(
                             "Failed to add verified client {} with cap {}",
                             client, client_cap,
                         ),
                     )
-                })?;
+                },
+            )?;
 
             st.verifiers = verifiers.flush().map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush verifiers")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verifiers")
             })?;
             st.verified_clients = verified_clients.flush().map_err(|e| {
-                e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
-                    "failed to flush verified clients",
-                )
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verified clients")
             })?;
 
             Ok(())
@@ -347,14 +317,14 @@ impl Actor {
 
         let client = resolve_to_id_addr(rt, &params.address).map_err(|e| {
             e.downcast_default(
-                ExitCode::USR_ILLEGAL_STATE,
+                ExitCode::ErrIllegalState,
                 format!("failed to resolve addr {} to ID addr", params.address),
             )
         })?;
 
         if params.deal_size < *MINIMUM_VERIFIED_DEAL_SIZE {
             return Err(actor_error!(
-                USR_ILLEGAL_ARGUMENT,
+                ErrIllegalArgument,
                 "Verified Dealsize {} is below minimum in usedbytes",
                 params.deal_size
             ));
@@ -364,24 +334,21 @@ impl Actor {
             let mut verified_clients =
                 make_map_with_root_and_bitwidth(&st.verified_clients, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
-                    e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
-                        "failed to load verified clients",
-                    )
+                    e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
                 })?;
 
             let BigIntDe(vc_cap) = verified_clients
                 .get(&client.to_bytes())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
+                        ExitCode::ErrIllegalState,
                         format!("failed to get verified client {}", &client),
                     )
                 })?
-                .ok_or_else(|| actor_error!(USR_NOT_FOUND, "no such verified client {}", client))?;
+                .ok_or_else(|| actor_error!(ErrNotFound, "no such verified client {}", client))?;
             if vc_cap.is_negative() {
                 return Err(actor_error!(
-                    USR_ILLEGAL_STATE,
+                    ErrIllegalState,
                     "negative cap for client {}: {}",
                     client,
                     vc_cap
@@ -390,7 +357,7 @@ impl Actor {
 
             if &params.deal_size > vc_cap {
                 return Err(actor_error!(
-                    USR_ILLEGAL_ARGUMENT,
+                    ErrIllegalArgument,
                     "Deal size of {} is greater than verifier_cap {} for verified client {}",
                     params.deal_size,
                     vc_cap,
@@ -406,33 +373,30 @@ impl Actor {
                     .delete(&client.to_bytes())
                     .map_err(|e| {
                         e.downcast_default(
-                            ExitCode::USR_ILLEGAL_STATE,
+                            ExitCode::ErrIllegalState,
                             format!("Failed to delete verified client {}", client),
                         )
                     })?
                     .ok_or_else(|| {
                         actor_error!(
-                            USR_ILLEGAL_STATE,
+                            ErrIllegalState,
                             "Failed to delete verified client {}: not found",
                             client
                         )
                     })?;
             } else {
-                verified_clients
-                    .set(client.to_bytes().into(), BigIntDe(new_vc_cap))
-                    .map_err(|e| {
+                verified_clients.set(client.to_bytes().into(), BigIntDe(new_vc_cap)).map_err(
+                    |e| {
                         e.downcast_default(
-                            ExitCode::USR_ILLEGAL_STATE,
+                            ExitCode::ErrIllegalState,
                             format!("Failed to update verified client {}", client),
                         )
-                    })?;
+                    },
+                )?;
             }
 
             st.verified_clients = verified_clients.flush().map_err(|e| {
-                e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
-                    "failed to flush verified clients",
-                )
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verified clients")
             })?;
             Ok(())
         })?;
@@ -450,7 +414,7 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(&*STORAGE_MARKET_ACTOR_ADDR))?;
         if params.deal_size < *MINIMUM_VERIFIED_DEAL_SIZE {
             return Err(actor_error!(
-                USR_ILLEGAL_ARGUMENT,
+                ErrIllegalArgument,
                 "Below minimum VerifiedDealSize requested in RestoreBytes: {}",
                 params.deal_size
             ));
@@ -458,27 +422,21 @@ impl Actor {
 
         let client = resolve_to_id_addr(rt, &params.address).map_err(|e| {
             e.downcast_default(
-                ExitCode::USR_ILLEGAL_STATE,
+                ExitCode::ErrIllegalState,
                 format!("failed to resolve addr {} to ID addr", params.address),
             )
         })?;
 
         let st: State = rt.state()?;
         if client == st.root_key {
-            return Err(actor_error!(
-                USR_ILLEGAL_ARGUMENT,
-                "Cannot restore allowance for Rootkey"
-            ));
+            return Err(actor_error!(ErrIllegalArgument, "Cannot restore allowance for Rootkey"));
         }
 
         rt.transaction(|st: &mut State, rt| {
             let mut verified_clients =
                 make_map_with_root_and_bitwidth(&st.verified_clients, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
-                    e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
-                        "failed to load verified clients",
-                    )
+                    e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
                 })?;
             let verifiers = make_map_with_root_and_bitwidth::<_, BigIntDe>(
                 &st.verifiers,
@@ -486,16 +444,16 @@ impl Actor {
                 HAMT_BIT_WIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load verifiers")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to load verifiers")
             })?;
 
             // validate we are NOT attempting to do this for a verifier
             let found = verifiers.contains_key(&client.to_bytes()).map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to get verifier")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to get verifier")
             })?;
             if found {
                 return Err(actor_error!(
-                    USR_ILLEGAL_ARGUMENT,
+                    ErrIllegalArgument,
                     "cannot restore allowance for a verifier {}",
                     client
                 ));
@@ -506,7 +464,7 @@ impl Actor {
                 .get(&client.to_bytes())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
+                        ExitCode::ErrIllegalState,
                         format!("failed to get verified client {}", &client),
                     )
                 })?
@@ -515,20 +473,15 @@ impl Actor {
 
             // Update to new cap
             let new_vc_cap = vc_cap + &params.deal_size;
-            verified_clients
-                .set(client.to_bytes().into(), BigIntDe(new_vc_cap))
-                .map_err(|e| {
-                    e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
-                        format!("Failed to put verified client {}", client),
-                    )
-                })?;
+            verified_clients.set(client.to_bytes().into(), BigIntDe(new_vc_cap)).map_err(|e| {
+                e.downcast_default(
+                    ExitCode::ErrIllegalState,
+                    format!("Failed to put verified client {}", client),
+                )
+            })?;
 
             st.verified_clients = verified_clients.flush().map_err(|e| {
-                e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
-                    "failed to flush verified clients",
-                )
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verified clients")
             })?;
             Ok(())
         })?;
@@ -572,7 +525,7 @@ impl ActorCode for Actor {
                 Self::restore_bytes(rt, rt.deserialize_params(params)?)?;
                 Ok(RawBytes::default())
             }
-            None => Err(actor_error!(SYS_INVALID_METHOD; "Invalid method")),
+            None => Err(actor_error!(SysErrInvalidMethod; "Invalid method")),
         }
     }
 }
