@@ -3,10 +3,10 @@
 
 use cid::Cid;
 use fil_actors_runtime::make_empty_map;
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
-use fvm_ipld_encoding::Cbor;
 use fvm_shared::address::Address;
+use fvm_shared::blockstore::Blockstore;
+use fvm_shared::encoding::tuple::*;
+use fvm_shared::encoding::Cbor;
 use fvm_shared::HAMT_BIT_WIDTH;
 
 #[derive(Serialize_tuple, Deserialize_tuple)]
@@ -22,11 +22,7 @@ impl State {
             .flush()
             .map_err(|e| anyhow::anyhow!("Failed to create empty map: {}", e))?;
 
-        Ok(State {
-            root_key,
-            verifiers: empty_map,
-            verified_clients: empty_map,
-        })
+        Ok(State { root_key, verifiers: empty_map, verified_clients: empty_map })
     }
 }
 
